@@ -9,9 +9,9 @@ test_that("replace_omv works", {
 
     tmpDF <- jmvReadWrite::bfi_sample2
     tmpDF <- cbind(tmpDF, data.frame(age_log = log(tmpDF$age)))
-    expect_equal(unname(sapply(replace_omv(dtaInp = tmpDF, rplLst = list(c(1, 6)), varExc = c("A1", "A2", "A3", "A4", "A5"))[2:26], function(x) c(sum(x == 1), sum(x == 6)))),
+    expect_equal(vapply(replace_omv(dtaInp = tmpDF, rplLst = list(c(1, 6)), varExc = c("A1", "A2", "A3", "A4", "A5"))[2:26], function(x) c(sum(x == 1), sum(x == 6)), integer(2), USE.NAMES = FALSE),
       t(matrix(c(78, 5, 8, 9, 6, rep(0, 20), 9, 82, 69, 106, 65, 49, 55, 47, 78, 75, 73, 76, 54, 68, 68, 81, 65, 72, 74, 94, 83, 95, 54, 110, 66), ncol = 2)))
-    expect_equal(unname(sapply(replace_omv(dtaInp = tmpDF, rplLst = list(c(1, 6)), varInc = c("A1", "A2", "A3", "A4", "A5"))[2:26], function(x) c(sum(x == 1), sum(x == 6)))),
+    expect_equal(vapply(replace_omv(dtaInp = tmpDF, rplLst = list(c(1, 6)), varInc = c("A1", "A2", "A3", "A4", "A5"))[2:26], function(x) c(sum(x == 1), sum(x == 6)), integer(2), USE.NAMES = FALSE),
       t(matrix(c(rep(0, 5), 2, 7, 7, 71, 45, 52, 51, 15, 14, 4, 59, 30, 42, 41, 64, 3, 75, 4, 4, 60,
                  87, 87, 77, 115, 71, 47, 48, 40, 7, 30, 21, 25, 39, 54, 64, 22, 35, 30, 33, 30, 80, 20, 50, 106, 6), ncol = 2)))
     expect_equal(jmvReadWrite::replace_omv(dtaInp = tmpDF, rplLst = list(c("66574", "Trial")))[244, "ID"],  "Trial")
@@ -21,8 +21,8 @@ test_that("replace_omv works", {
     expect_equal(unname(colSums(jmvReadWrite::replace_omv(dtaInp = tmpDF, rplLst = list(c("4.", "0.")), whlTrm = FALSE) != tmpDF)), c(rep(0, 29), 5))
     expect_equal(mean(jmvReadWrite::replace_omv(dtaInp = tmpDF, rplLst = list(c("4.", "0.")), whlTrm = FALSE)[, "age_log"]), 3.1970427)
 
-    expect_warning(expect_equal(unname(sapply(replace_omv(dtaInp = tmpDF, rplLst = list(c(1, 6)), varInc = c("A1", "A2", "A3", "A4", "A5"), varExc = c("ID"))[2:26],
-      function(x) c(sum(x == 1), sum(x == 6)))),
+    expect_warning(expect_equal(vapply(replace_omv(dtaInp = tmpDF, rplLst = list(c(1, 6)), varInc = c("A1", "A2", "A3", "A4", "A5"), varExc = c("ID"))[2:26],
+      function(x) c(sum(x == 1), sum(x == 6)), integer(2), USE.NAMES = FALSE),
       t(matrix(c(rep(0, 5), 2, 7, 7, 71, 45, 52, 51, 15, 14, 4, 59, 30, 42, 41, 64, 3, 75, 4, 4, 60,
                  87, 87, 77, 115, 71, 47, 48, 40, 7, 30, 21, 25, 39, 54, 64, 22, 35, 30, 33, 30, 80, 20, 50, 106, 6), ncol = 2))),
       regexp = "Both varInc and varExc are given, varInc takes precedence\\.")
